@@ -409,7 +409,7 @@ DECLARE_bool(stop_logging_if_full_disk);
 #ifdef NDEBUG
 #define COMPACT_GOOGLE_LOG_DFATAL COMPACT_GOOGLE_LOG_ERROR
 #elif GOOGLE_STRIP_LOG <= 3
-#define COMPACT_GOOGLE_LOG_DFATAL LogMessage( \
+#define COMPACT_GOOGLE_LOG_DFATAL google::LogMessage( \
       __FILE__, __LINE__, google::FATAL)
 #else
 #define COMPACT_GOOGLE_LOG_DFATAL google::NullStreamFatal()
@@ -482,6 +482,9 @@ namespace google {
 // specified by argv0 in log outputs.
 GOOGLE_GLOG_DLL_DECL void InitGoogleLogging(const char* argv0);
 
+// Shutdown google's logging library.
+GOOGLE_GLOG_DLL_DECL void ShutdownGoogleLogging();
+
 // Install a function which will be called after LOG(FATAL).
 GOOGLE_GLOG_DLL_DECL void InstallFailureFunction(void (*fail_func)());
 
@@ -600,7 +603,7 @@ std::string* MakeCheckOpString(const t1& v1, const t2& v2, const char* names) {
   // It means that we cannot use stl_logging if compiler doesn't
   // support using expression for operator.
   // TODO(hamaji): Figure out a way to fix.
-#if 0
+#if 1
   using ::operator<<;
 #endif
   std::strstream ss;
@@ -652,7 +655,7 @@ DEFINE_CHECK_OP_IMPL(_GT, > )
 // file is included).  Save the current meaning now and use it 
 // in the macro.
 typedef std::string _Check_string;
-#define CHECK_OP_LOG(name, op, val1, val2, log) \
+#define CHECK_OP_LOG(name, op, val1, val2, log)                         \
   while (google::_Check_string* _result =                \
          google::Check##name##Impl(                      \
              google::GetReferenceableValue(val1),        \
@@ -663,11 +666,12 @@ typedef std::string _Check_string;
 #else
 // In optimized mode, use CheckOpString to hint to compiler that
 // the while condition is unlikely.
-#define CHECK_OP_LOG(name, op, val1, val2, log) \
-  while (google::CheckOpString _result = \
-         google::Check##name##Impl(GetReferenceableValue(val1), \
-                           GetReferenceableValue(val2), \
-                           #val1 " " #op " " #val2)) \
+#define CHECK_OP_LOG(name, op, val1, val2, log)                         \
+  while (google::CheckOpString _result =                 \
+         google::Check##name##Impl(                      \
+             google::GetReferenceableValue(val1),        \
+             google::GetReferenceableValue(val2),        \
+             #val1 " " #op " " #val2))                                  \
     log(__FILE__, __LINE__, _result).stream()
 #endif  // STATIC_ANALYSIS, !NDEBUG
 
@@ -888,6 +892,7 @@ enum PRIVATE_Counter {COUNTER};
 #define DCHECK_LT(val1, val2) CHECK_LT(val1, val2)
 #define DCHECK_GE(val1, val2) CHECK_GE(val1, val2)
 #define DCHECK_GT(val1, val2) CHECK_GT(val1, val2)
+#define DCHECK_NOTNULL(val) CHECK_NOTNULL(val)
 #define DCHECK_STREQ(str1, str2) CHECK_STREQ(str1, str2)
 #define DCHECK_STRCASEEQ(str1, str2) CHECK_STRCASEEQ(str1, str2)
 #define DCHECK_STRNE(str1, str2) CHECK_STRNE(str1, str2)
@@ -942,6 +947,8 @@ enum PRIVATE_Counter {COUNTER};
   while (false) \
     CHECK_GT(val1, val2)
 
+#define DCHECK_NOTNULL(val) (val)
+
 #define DCHECK_STREQ(str1, str2) \
   while (false) \
     CHECK_STREQ(str1, str2)
@@ -1179,7 +1186,7 @@ inline void LogAtLevel(int const severity, std::string const &msg) {
 // version since there are two advantages: 1. this version outputs the
 // file name and the line number where this macro is put like other
 // LOG macros, 2. this macro can be used as C++ stream.
-#define LOG_AT_LEVEL(severity) LogMessage(__FILE__, __LINE__, severity).stream()
+#define LOG_AT_LEVEL(severity) google::LogMessage(__FILE__, __LINE__, severity).stream()
 
 // A small helper for CHECK_NOTNULL().
 template <typename T>
